@@ -1,25 +1,25 @@
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
 /* exported init */
-const { Clutter, St } = imports.gi;
+const { Clutter, GObject, St } = imports.gi;
 
 const Main = imports.ui.main;
 const Workspace = imports.ui.workspace;
 const WorkspacesView = imports.ui.workspacesView;
 
-var MyWindowOverlay = class extends Workspace.WindowOverlay {
+class MyWindowOverlay extends Workspace.WindowOverlay {
     constructor(windowClone, parentActor) {
         super(windowClone, parentActor);
 
         this._id = null;
         this._text = new St.Label({
             style_class: 'extension-windowsNavigator-window-tooltip',
-            visible: false
+            visible: false,
         });
         parentActor.add_actor(this._text);
     }
 
     showTooltip() {
-        this._text.raise_top();
+        this._parentActor.set_child_below_sibling(this._text, null);
         this._text.show();
         this._text.text = (this._windowClone.slotId + 1).toString();
     }
@@ -37,36 +37,38 @@ var MyWindowOverlay = class extends Workspace.WindowOverlay {
         let textX = cloneX - 2;
         let textY = cloneY - 2;
         this._text.set_position(Math.floor(textX) + 5, Math.floor(textY) + 5);
-        this._text.raise_top();
+        this._parentActor.set_child_below_sibling(this._text, null);
     }
-};
+}
 
-var MyWorkspace = class extends Workspace.Workspace {
-    constructor(metaWorkspace, monitorIndex) {
-        super(metaWorkspace, monitorIndex);
+var MyWorkspace = GObject.registerClass(
+class MyWorkspace extends Workspace.Workspace {
+    _init(metaWorkspace, monitorIndex) {
+        super._init(metaWorkspace, monitorIndex);
 
         if (metaWorkspace && metaWorkspace.index() < 9) {
             this._tip = new St.Label({
                 style_class: 'extension-windowsNavigator-window-tooltip',
-                visible: false
+                visible: false,
             });
-            this.actor.add_actor(this._tip);
+            this.add_actor(this._tip);
 
-            this.actor.connect('notify::scale-x', () => {
-                this._tip.set_scale(1 / this.actor.scale_x, 1 / this.actor.scale_x);
+            this.connect('notify::scale-x', () => {
+                this._tip.set_scale(1 / this.scale_x, 1 / this.scale_x);
             });
-        } else
+        } else {
             this._tip = null;
+        }
     }
 
     showTooltip() {
-        if (this._tip == null || this._actualGeometry == null)
+        if (!this._tip || !this._actualGeometry)
             return;
         this._tip.text = (this.metaWorkspace.index() + 1).toString();
 
         // Hand code this instead of using _getSpacingAndPadding
         // because that fails on empty workspaces
-        let node = this.actor.get_theme_node();
+        let node = this.get_theme_node();
         let padding = {
             left: node.get_padding(St.Side.LEFT),
             top: node.get_padding(St.Side.TOP),
@@ -78,11 +80,11 @@ var MyWorkspace = class extends Workspace.Workspace {
         this._tip.x = area.x;
         this._tip.y = area.y;
         this._tip.show();
-        this._tip.raise_top();
+        this.set_child_below_sibling(this._tip, null);
     }
 
     hideTooltip() {
-        if (this._tip == null)
+        if (!this._tip)
             return;
         if (!this._tip.get_parent())
             return;
@@ -91,7 +93,7 @@ var MyWorkspace = class extends Workspace.Workspace {
 
     getWindowWithTooltip(id) {
         for (let i = 0; i < this._windows.length; i++) {
-            if ((this._windows[i].slotId + 1) == id)
+            if (this._windows[i].slotId + 1 === id)
                 return this._windows[i].metaWindow;
         }
         return null;
@@ -99,22 +101,23 @@ var MyWorkspace = class extends Workspace.Workspace {
 
     showWindowsTooltips() {
         for (let i in this._windowOverlays) {
-            if (this._windowOverlays[i] != null)
+            if (this._windowOverlays[i])
                 this._windowOverlays[i].showTooltip();
         }
     }
 
     hideWindowsTooltips() {
         for (let i in this._windowOverlays) {
-            if (this._windowOverlays[i] != null)
+            if (this._windowOverlays[i])
                 this._windowOverlays[i].hideTooltip();
         }
     }
-};
+});
 
-var MyWorkspacesView = class extends WorkspacesView.WorkspacesView {
-    constructor(width, height, x, y, workspaces) {
-        super(width, height, x, y, workspaces);
+var MyWorkspacesView = GObject.registerClass(
+class MyWorkspacesView extends WorkspacesView.WorkspacesView {
+    _init(width, height, x, y, workspaces) {
+        super._init(width, height, x, y, workspaces);
 
         this._pickWorkspace = false;
         this._pickWindow = false;
@@ -132,7 +135,7 @@ var MyWorkspacesView = class extends WorkspacesView.WorkspacesView {
     }
 
     _hideTooltips() {
-        if (global.stage.get_key_focus() == global.stage)
+        if (global.stage.get_key_focus() === global.stage)
             global.stage.set_key_focus(this._prevFocusActor);
         this._pickWindow = false;
         for (let i = 0; i < this._workspaces.length; i++)
@@ -148,25 +151,25 @@ var MyWorkspacesView = class extends WorkspacesView.WorkspacesView {
 
     _onKeyRelease(s, o) {
         if (this._pickWindow &&
-            (o.get_key_symbol() == Clutter.KEY_Alt_L ||
-             o.get_key_symbol() == Clutter.KEY_Alt_R))
+            (o.get_key_symbol() === Clutter.KEY_Alt_L ||
+             o.get_key_symbol() === Clutter.KEY_Alt_R))
             this._hideTooltips();
         if (this._pickWorkspace &&
-            (o.get_key_symbol() == Clutter.KEY_Control_L ||
-             o.get_key_symbol() == Clutter.KEY_Control_R))
+            (o.get_key_symbol() === Clutter.KEY_Control_L ||
+             o.get_key_symbol() === Clutter.KEY_Control_R))
             this._hideWorkspacesTooltips();
     }
 
     _onKeyPress(s, o) {
-        let viewSelector = Main.overview.viewSelector;
-        if (viewSelector._activePage != viewSelector._workspacesPage)
+        let { viewSelector } = Main.overview;
+        if (viewSelector._activePage !== viewSelector._workspacesPage)
             return false;
 
         let workspaceManager = global.workspace_manager;
 
-        if ((o.get_key_symbol() == Clutter.KEY_Alt_L ||
-             o.get_key_symbol() == Clutter.KEY_Alt_R)
-            && !this._pickWorkspace) {
+        if ((o.get_key_symbol() === Clutter.KEY_Alt_L ||
+             o.get_key_symbol() === Clutter.KEY_Alt_R) &&
+            !this._pickWorkspace) {
             this._prevFocusActor = global.stage.get_key_focus();
             global.stage.set_key_focus(null);
             this._active = workspaceManager.get_active_workspace_index();
@@ -174,9 +177,9 @@ var MyWorkspacesView = class extends WorkspacesView.WorkspacesView {
             this._workspaces[workspaceManager.get_active_workspace_index()].showWindowsTooltips();
             return true;
         }
-        if ((o.get_key_symbol() == Clutter.KEY_Control_L ||
-             o.get_key_symbol() == Clutter.KEY_Control_R)
-            && !this._pickWindow) {
+        if ((o.get_key_symbol() === Clutter.KEY_Control_L ||
+             o.get_key_symbol() === Clutter.KEY_Control_R) &&
+            !this._pickWindow) {
             this._prevFocusActor = global.stage.get_key_focus();
             global.stage.set_key_focus(null);
             this._pickWorkspace = true;
@@ -185,17 +188,17 @@ var MyWorkspacesView = class extends WorkspacesView.WorkspacesView {
             return true;
         }
 
-        if (global.stage.get_key_focus() != global.stage)
+        if (global.stage.get_key_focus() !== global.stage)
             return false;
 
         // ignore shift presses, they're required to get numerals in azerty keyboards
         if ((this._pickWindow || this._pickWorkspace) &&
-            (o.get_key_symbol() == Clutter.KEY_Shift_L ||
-             o.get_key_symbol() == Clutter.KEY_Shift_R))
+            (o.get_key_symbol() === Clutter.KEY_Shift_L ||
+             o.get_key_symbol() === Clutter.KEY_Shift_R))
             return true;
 
         if (this._pickWindow) {
-            if (this._active != workspaceManager.get_active_workspace_index()) {
+            if (this._active !== workspaceManager.get_active_workspace_index()) {
                 this._hideTooltips();
                 return false;
             }
@@ -237,7 +240,7 @@ var MyWorkspacesView = class extends WorkspacesView.WorkspacesView {
         }
         return false;
     }
-};
+});
 
 class Extension {
     constructor() {
